==> ogre-next-debug-2.3.3-2-x86_64.pkg.tar.zst: usr/src/debug/ogre-next/ogre-next-2.3.3/Samples/2.0/ApiUsage/ShadowMapFromCode/ShadowMapFromCodeGameState.h <==

#ifndef _Demo_ShadowMapFromCodeGameState_H_
#define _Demo_ShadowMapFromCodeGameState_H_

#include "OgrePrerequisites.h"
#include "OgreOverlayPrerequisites.h"
#include "OgreOverlay.h"
#include "TutorialGameState.h"


namespace Demo
{
    class ShadowMapFromCodeGameState : public TutorialGameState
    {
        Ogre::SceneNode     *mSceneNode[16];

        Ogre::SceneNode     *mLightNodes[3];

        bool                mAnimateObjects;

        Ogre::v1::Overlay *mDebugOverlayPSSM;
        Ogre::v1::Overlay *mDebugOverlaySpotlights;

        /// Chooses between compute & pixel shader based ESM shadow node.
        /// Compute shader filter is faster for large kernels; but beware
        /// of mobile hardware where compute shaders are slow)
        /// Pixel shader filter is faster for small kernels, also to use as a fallback
        /// on GPUs that don't support compute shaders, or where compute shaders are slow).
        /// For reference large kernels means kernelRadius > 2 (approx)
        const char* chooseEsmShadowNode(void);
        void setupShadowNode( bool forEsm );

        virtual void generateDebugText( float timeSinceLast, Ogre::String &outText );

        void createShadowMapDebugOverlays(void);
        void destroyShadowMapDebugOverlays(void);

    public:
        ShadowMapFromCodeGameState( const Ogre::String &helpDescription );

        virtual void createScene01(void);

        virtual void update( float timeSinceLast );

        virtual void keyReleased( const SDL_KeyboardEvent &arg );
    };
}

#endif

==> ogre-next-debug-3.0.0-1-x86_64.pkg.tar.zst: usr/src/debug/ogre-next/ogre-next-3.0.0/Samples/2.0/ApiUsage/ShadowMapFromCode/ShadowMapFromCodeGameState.h <==

#ifndef _Demo_ShadowMapFromCodeGameState_H_
#define _Demo_ShadowMapFromCodeGameState_H_

#include "OgreOverlay.h"
#include "OgreOverlayPrerequisites.h"
#include "OgrePrerequisites.h"

#include "TutorialGameState.h"

#define USE_STATIC_BRANCHING_FOR_SHADOWMAP_LIGHTS 1

namespace Demo
{
    class ShadowMapFromCodeGameState : public TutorialGameState
    {
        Ogre::SceneNode *mSceneNode[16];

#ifdef USE_STATIC_BRANCHING_FOR_SHADOWMAP_LIGHTS
        Ogre::SceneNode *mLightNodes[5];
#else
        Ogre::SceneNode *mLightNodes[3];
#endif

        bool mAnimateObjects;

        Ogre::v1::Overlay *mDebugOverlayPSSM;
        Ogre::v1::Overlay *mDebugOverlaySpotlights;

        /// Chooses between compute & pixel shader based ESM shadow node.
        /// Compute shader filter is faster for large kernels; but beware
        /// of mobile hardware where compute shaders are slow)
        /// Pixel shader filter is faster for small kernels, also to use as a fallback
        /// on GPUs that don't support compute shaders, or where compute shaders are slow).
        /// For reference large kernels means kernelRadius > 2 (approx)
        const char *chooseEsmShadowNode();
        void setupShadowNode( bool forEsm );

        void generateDebugText( float timeSinceLast, Ogre::String &outText ) override;

        void createShadowMapDebugOverlays();
        void destroyShadowMapDebugOverlays();

    public:
        ShadowMapFromCodeGameState( const Ogre::String &helpDescription );

        void createScene01() override;

        void update( float timeSinceLast ) override;

        void keyReleased( const SDL_KeyboardEvent &arg ) override;
    };
}  // namespace Demo

#endif
